/*
    Kernel mode web server for Windows.
    Copyright (C) 2006-2009 Bo Brantn.
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <ntddk.h>
#include "ksocket.h"

#if defined(_M_IX86) || defined(_M_IA64)
#define _LITTLE_ENDIAN TRUE
#endif

#if !defined(_LITTLE_ENDIAN) && !defined(_BIG_ENDIAN)
#error Define _LITTLE_ENDIAN or _BIG_ENDIAN
#endif

static u_long bswap32(u_long x)
{
    return  ((x << 24) & 0xff000000ul) |
            ((x <<  8) & 0x00ff0000ul) |
            ((x >>  8) & 0x0000ff00ul) |
            ((x >> 24) & 0x000000fful);
}

static u_short bswap16(u_short x)
{
    return  ((x << 8) & 0xff00u) |
            ((x >> 8) & 0x00ffu);
}

u_long __cdecl htonl(u_long hostlong)
{
#if defined(_LITTLE_ENDIAN)
    return bswap32(hostlong);
#else
    return hostlong;
#endif
}

u_short __cdecl htons(u_short hostshort)
{
#if defined(_LITTLE_ENDIAN)
    return bswap16(hostshort);
#else
    return hostshort;
#endif
}

u_long __cdecl ntohl(u_long netlong)
{
#if defined(_LITTLE_ENDIAN)
    return bswap32(netlong);
#else
    return netlong;
#endif
}

u_short __cdecl ntohs(u_short netshort)
{
#if defined(_LITTLE_ENDIAN)
    return bswap16(netshort);
#else
    return netshort;
#endif
}
